@@ -253,7 +253,9 @@ class Client(object):
             raw_obj = dict(ret)
             for formula_idx, formula in enumerate(params['formulas']):
                 ret[formula] = ret['data'][formula_idx]
-            del ret['quota'], ret['quotaRemaining'], ret['dt'], ret['data']
+            del ret['quota'], ret['quotaRemaining'], ret['data']
+            if ret.get('dt'):
+                del ret['dt']
             ret = pandas.DataFrame(data=ret)
             ret.attrs['raw_obj'] = raw_obj
 
